# define arches for PA and SA
%global golang_arches   %{ix86} x86_64 %{arm}
%global gccgo_arches    %{power64} s390x aarch64
%global go_arches       %golang_arches %gccgo_arches

%define debug_package %{nil}

# gopath macro not defined for gccgo_arches
%ifarch %{gccgo_arches}
%global gopath          %{_datadir}/gocode
%endif

# Override to specify version for buildrequiresgo and requiresgo
%global gccgo_version %{nil}
%global golang_version %{nil}

# To provide easy way to set Go compiler, with possible version override
%ifarch %golang_arches
%define gocompiler golang %{?golang_version}
%else
%define gocompiler gcc-go %{?gccgo_version}
%endif

# Chose the correct compiler
%ifarch %golang_arches
%define gobuild go build -compiler gc
%else
%define gobuild go build -compiler gccgo -gccgoflags "$RPM_OPT_FLAGS"
%endif

# Test with the correct compiler
%ifarch %golang_arches \
%define gotest go test -compiler gc
%else
%define gotest go test -compiler gccgo -gccgoflags "$RPM_OPT_FLAGS"
%endif

%if 0%{?fedora}
# https://bugzilla.redhat.com/show_bug.cgi?id=995136#c12
%global _dwz_low_mem_die_limit 0
%endif
%global provider        github
%global provider_tld    com
%global project         cpuguy83
%global repo            go-md2man
# https://github.com/cpuguy83/go-md2man
%global import_path     %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit          2831f11f66ff4008f10e2cd7ed9a85e3d3fc2bed
%global shortcommit     %(c=%{commit}; echo ${c:0:7})
%global golang_version  >= 1.2.1-3

Name:           golang-%{provider}-%{project}-%{repo}
Version:        1
Release:        7%{?dist}
Summary:        Process markdown into manpages
License:        MIT
URL:            https://%{import_path}
Source0:        https://%{import_path}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz
ExclusiveArch:  %{go_arches}

BuildRequires:  %{gocompiler}
BuildRequires:  golang(github.com/russross/blackfriday)
Provides:       %{repo} = %{version}-%{release}

%description
%{repo} is a golang tool using blackfriday to process markdown into
manpages.

%package devel
BuildArch:      noarch
Summary:        A golang registry for global request variables
BuildRequires:  %{gocompiler}
BuildRequires:  golang(github.com/russross/blackfriday)
Provides:       golang(%{import_path}) = %{version}-%{release}
Provides:       golang(%{import_path}/mangen) = %{version}-%{release}

%description devel
%{repo} is a golang tool using blackfriday to process markdown into
manpages.

This package contains library source intended for building other packages
which use %{project}/%{repo}.

%prep
%setup -q -n %{repo}-%{commit}

%build
%if 0%{?fedora}
function gobuild { %{gobuild} -a -ldflags "-B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \n')" -v -x "$@"; }
%else
# no debug info for rhel so far
function gobuild { %{gobuild} "$@"; }
%endif

mkdir -p _build/src/%{provider}.%{provider_tld}/%{project}
ln -s $(pwd) ./_build/src/%{import_path}
export GOPATH=$(pwd)/_build:%{gopath}
pushd $(pwd)/_build/src
gobuild %{import_path}
popd

%install
install -d -p %{buildroot}%{gopath}/src/%{import_path}/mangen
cp -pav *.go %{buildroot}%{gopath}/src/%{import_path}/
cp -pav mangen/*.go %{buildroot}%{gopath}/src/%{import_path}/mangen

# install go-md2man binary
install -d %{buildroot}%{_bindir}
install -p -m 755 ./_build/src/%{repo} %{buildroot}%{_bindir}

%check
#no test files so far

%files
%if 0%{?fedora}
%license LICENSE.md
%doc README.md
%else
%doc LICENSE.md README.md
%endif
%{_bindir}/%{repo}

%files devel
%if 0%{?fedora}
%license LICENSE.md
%doc README.md
%else
%doc LICENSE.md README.md
%endif
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%{gopath}/src/%{import_path}

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 19 2015 jchaloup <jchaloup@redhat.com> - 1-6
- Remove runtime deps of devel on golang
- Polish spec file
  related: #1222796

* Sun May 17 2015 jchaloup <jchaloup@redhat.com> - 1-5
- Add debug info
- Add license
- Update spec file to build on secondary architectures as well
  related: #1222796

* Wed Feb 25 2015 jchaloup <jchaloup@redhat.com> - 1-4
- Bump to upstream 2831f11f66ff4008f10e2cd7ed9a85e3d3fc2bed
  related: #1156492

* Wed Feb 25 2015 jchaloup <jchaloup@redhat.com> - 1-3
- Add commit and shortcommit global variable
  related: #1156492

* Mon Oct 27 2014 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1-2
- Resolves: rhbz#1156492 - initial fedora upload
- quiet setup
- no test files, disable check

* Thu Sep 11 2014 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1-1
- Initial package
